==> simm-common-0.0.1-20180108.063556-26-sources.jar: com/simm/common/bean/BaseBean.java <==
package com.simm.common.bean;

import java.util.Date;

import org.apache.commons.lang3.builder.ReflectionToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

/**
 * 
 * @Description 父级实体,所有的实体类都需继承该类
 *
 * @author YingJH
 * @Date 2017年9月22日
 * @version v1.0
 */
public class BaseBean implements java.io.Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String createBy;

	private Date createTime;

	private String lastUpdateBy;

	private Date lastUpdateTime;
	
	private String remark;
	
	/**
	 * 以下为扩展字段----------------
	 */
	
	//关键字
    private String searchKey;
    
    private Date startDate;
    
    private Date endDate;
    
    public Date getStartDate() {
		return startDate;
	}

	public void setStartDate(Date startDate) {
		this.startDate = startDate;
	}

	public Date getEndDate() {
		return endDate;
	}

	public void setEndDate(Date endDate) {
		this.endDate = endDate;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getSearchKey() {
		return searchKey;
	}
    
	public void setSearchKey(String searchKey) {
		this.searchKey = searchKey;
	}
	
	/**
	 * 跳转页数，页数是从第一页是从1开始计算的
	 */
	private Integer pageNum = 1;
	/**
	 * 每页的记录数(每页尺寸)
	 */
	private Integer numPerPage = 10;
	
	public Integer getPageNum() {
		return pageNum;
	}

	public void setPageNum(Integer pageNum) {
		this.pageNum = pageNum;
	}

	public Integer getNumPerPage() {
		return numPerPage;
	}

	public void setNumPerPage(Integer numPerPage) {
		this.numPerPage = numPerPage;
	}

	public String getCreateBy() {
		return createBy;
	}

	public void setCreateBy(String createBy) {
		this.createBy = createBy;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public String getLastUpdateBy() {
		return lastUpdateBy;
	}

	public void setLastUpdateBy(String lastUpdateBy) {
		this.lastUpdateBy = lastUpdateBy;
	}

	public Date getLastUpdateTime() {
		return lastUpdateTime;
	}

	public void setLastUpdateTime(Date lastUpdateTime) {
		this.lastUpdateTime = lastUpdateTime;
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return new ReflectionToStringBuilder(this, ToStringStyle.SHORT_PREFIX_STYLE).toString();
	}
}

==> simm-common-0.0.1-20180516.032842-48-sources.jar: com/simm/common/bean/BaseBean.java <==
package com.simm.common.bean;

import java.util.Date;

import org.apache.commons.lang3.builder.ReflectionToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

/**
 * 
 * @Description 父级实体,所有的实体类都需继承该类
 *
 * @author YingJH
 * @Date 2017年9月22日
 * @version v1.0
 */
public class BaseBean implements java.io.Serializable {

	private static final long serialVersionUID = 7829614645252520904L;

	private String createBy;

	private Date createTime;

	private String lastUpdateBy;

	private Date lastUpdateTime;
	
	private String remark;
	
	private String checkAdmin;
	
	/**
	 * 以下为扩展字段----------------
	 */
	
	//关键字
    private String searchKey;
    
    private Date startDate;
    
    private Date endDate;
    
    public Date getStartDate() {
		return startDate;
	}

	public void setStartDate(Date startDate) {
		this.startDate = startDate;
	}

	public Date getEndDate() {
		return endDate;
	}

	public void setEndDate(Date endDate) {
		this.endDate = endDate;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getSearchKey() {
		return searchKey;
	}
    
	public void setSearchKey(String searchKey) {
		this.searchKey = searchKey;
	}
	
	/**
	 * 跳转页数，页数是从第一页是从1开始计算的
	 */
	private Integer pageNum = 1;
	/**
	 * 每页的记录数(每页尺寸)
	 */
	private Integer pageSize = 10;
	
	public Integer getPageNum() {
		return pageNum;
	}

	public void setPageNum(Integer pageNum) {
		this.pageNum = pageNum;
	}

	public Integer getPageSize() {
		return pageSize;
	}

	public void setPageSize(Integer pageSize) {
		this.pageSize = pageSize;
	}

	public String getCreateBy() {
		return createBy;
	}

	public void setCreateBy(String createBy) {
		this.createBy = createBy;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public String getLastUpdateBy() {
		return lastUpdateBy;
	}

	public void setLastUpdateBy(String lastUpdateBy) {
		this.lastUpdateBy = lastUpdateBy;
	}

	public Date getLastUpdateTime() {
		return lastUpdateTime;
	}

	public void setLastUpdateTime(Date lastUpdateTime) {
		this.lastUpdateTime = lastUpdateTime;
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return new ReflectionToStringBuilder(this, ToStringStyle.SHORT_PREFIX_STYLE).toString();
	}
}
